@@ -280,6 +280,7 @@ class BuildGraphCommand(BuildAwareCommand):
         targets: list[str]
         resume: bool
         restart: bool
+        no_save: bool
 
     def init_parser(self, parser: argparse.ArgumentParser) -> None:
         super().init_parser(parser)
@@ -290,6 +291,7 @@ class BuildGraphCommand(BuildAwareCommand):
             choices=("all",),
             help="load previous build state, but discard existing results (requires --resume)",
         )
+        parser.add_argument("--no-save", action="store_true", help="do not save the new build state")
 
     def resolve_tasks(self, args: Args, context: Context) -> list[Task]:
         return context.resolve_tasks(args.targets or None)
@@ -334,7 +336,8 @@ class BuildGraphCommand(BuildAwareCommand):
         try:
             return self.execute_with_graph(context, graph, args)
         finally:
-            save_state(state_dir, graph)
+            if not args.no_save:
+                save_state(state_dir, graph)
 
     def execute_with_graph(self, context: Context, graph: TaskGraph, args: Args) -> int | None:
         raise NotImplementedError
