@@ -2,7 +2,9 @@ from __future__ import annotations
 
 import argparse
 import io
+import os
 import sys
+import textwrap
 from typing import Any
 
 from kraken.core import Context, GroupTask, Property, Task, TaskGraph, TaskStatus, TaskStatusType
@@ -14,6 +16,20 @@ from ..executor import COLORS_BY_STATUS, status_to_text
 from .base import BuildGraphCommand, print
 
 
+def get_terminal_width(default: int = 80) -> int:
+    """Returns the terminal width through :func:`os.get_terminal_size`, falling back to the `COLUMNS`
+    environment variable. If neither is available, return *default*."""
+
+    try:
+        terminal_width = os.get_terminal_size().columns
+    except OSError:
+        try:
+            terminal_width = int(os.getenv("COLUMNS", ""))
+        except ValueError:
+            terminal_width = default
+    return terminal_width
+
+
 class LsCommand(BuildGraphCommand):
     """list all tasks"""
 
@@ -38,8 +54,11 @@ class LsCommand(BuildGraphCommand):
         print(colored("Tasks", "blue", attrs=["bold", "underline"]))
         print()
 
+        width = get_terminal_width(120)
+
         def _print_task(task: Task) -> None:
             line = [task.path.ljust(longest_name)]
+            remaining_width = width - len(line[0])
             if task in required_tasks:
                 line[0] = colored(line[0], "green")
             if task.default:
@@ -47,9 +66,18 @@ class LsCommand(BuildGraphCommand):
             status = graph.get_status(task)
             if status is not None:
                 line.append(f"[{status_to_text(status)}]")
+                remaining_width -= 2 + len(status_to_text(status, colored=False)) + 1
             description = task.get_description()
             if description:
-                line.append(description)
+                remaining_width -= 2
+                for part in textwrap.wrap(
+                    description,
+                    remaining_width,
+                    subsequent_indent=(width - remaining_width) * " ",
+                ):
+                    line.append(part)
+                    line.append("\n")
+                line.pop()
             print("  " + " ".join(line))
 
         def sort_key(task: Task) -> str:
