@@ -17,8 +17,11 @@ COLORS_BY_STATUS = {
 }
 
 
-def status_to_text(status: TaskStatus) -> str:
-    message = colored(status.type.name, COLORS_BY_STATUS.get(status.type))
+def status_to_text(status: TaskStatus, colored: bool = True) -> str:
+    if colored:
+        message = colored(status.type.name, COLORS_BY_STATUS.get(status.type))
+    else:
+        message = status.type.name
     if status.message:
         message += f" ({status.message})"
     return message
